---------------------------------------------------
-- WAVERIDER SETTINGS
---------------------------------------------------
config.title = "Mach 7 flow over a Power Law 2D body"
print(config.title)


l = 1.5 --length 1.5m

-- SOLVER SETTINGS
nblocks = 16

-- TUNNEL CONDITIONS
--T = 70; p = 310; u = 1180; M = 7.0; rho = 0.0155

-- WAVERIDER FLOW CONDITIONS
T = 247.58; p = 328.82; u = 2614.50; M = 7.00; rho = 0.0033

nsp, nmodes = setGasModel('ideal-air-gas-model.lua')
print("GasModel set to ideal air. nsp= ", nsp, " nmodes= ", nmodes)
initial = FlowState:new{p=100, T=T, velx=0.5*u, vely=0.0}
inflow = FlowState:new{p=p, T=T, velx=u, vely=0.0}

-- IMPORT GRIDPRO GRID
gproGrid = "powerlaw_mesh_pw.dat"
grid = importGridproGrid(gproGrid, 1)
grid90 = rotateGridproBlocks(grid[1],"West","North")

-- Define the flow-solution blocks.
blk = FBArray:new{grid=grid90,
                  initialState=initial,
                  bcList={west=InFlowBC_ShockFitting:new{flowState=inflow},
                          north=OutFlowBC_Simple:new{},
                          east=WallBC_WithSlip:new{},
                          south=WallBC_WithSlip:new{}},
                  njb=nblocks, nib=1}

-- Set a few more config options
body_flow_time = l/u
print("body_flow_time=", body_flow_time)
config.flux_calculator = "adaptive_hanel_ausmdv"
config.dimensions = 2
config.axisymmetric = true


config.max_time = 4*body_flow_time
config.max_step = 400000
config.dt_init = 1.0e-8

config.dt_plot = 0.5*body_flow_time
-- We want the starting pulse to clear the flow domain before allowing
-- the inflow boundary to move down into the shock location.
-- Until then, the shock is too complicated.
config.shock_fitting_delay = 1.2*body_flow_time
config.grid_motion = "shock_fitting"

config.max_invalid_cells = 20
config.adjust_invalid_cell_data = true
config.report_invalid_cells = false

config.gasdynamic_update_scheme = "backward_euler"
--config.cfl_schedule = {{0.0, 10.0}, {1.0*body_flow_time, 10.0}, {1.2*body_flow_time, 0.8}, {3.0*body_flow_time, 4.0}}
config.cfl_value = 6.0

--config.gasdynamic_update_scheme = "moving-grid-1-stage"
--config.cfl_schedule = {{0.0, 0.8}, {1.0*body_flow_time, 0.8}, {1.2*body_flow_time, 0.3}, {3.0*body_flow_time, 0.5}}

config.interpolation_order = 2
config.interpolation_delay = 1.1*body_flow_time
config.compression_tolerance = -0.1
config.shock_detector_smoothing = 2
